Index: chrome/browser/resources/tracing/profiling_view.js |
diff --git a/chrome/browser/resources/gpu_internals/profiling_view.js b/chrome/browser/resources/tracing/profiling_view.js |
similarity index 94% |
rename from chrome/browser/resources/gpu_internals/profiling_view.js |
rename to chrome/browser/resources/tracing/profiling_view.js |
index eb8a2e2e28a4b724b2e7b43e6a5d6bf8b17b804f..a4f13de13cf9635ff91f4c5d2aa38bdf99c3700b 100644 |
--- a/chrome/browser/resources/gpu_internals/profiling_view.js |
+++ b/chrome/browser/resources/tracing/profiling_view.js |
@@ -4,14 +4,14 @@ |
/** |
* @fileoverview ProfilingView visualizes GPU_TRACE events using the |
* gpu.Timeline component. |
*/ |
-cr.define('gpu', function() { |
+cr.define('tracing', function() { |
/** |
* ProfilingView |
* @constructor |
- * @extends {gpu.Tab} |
+ * @extends {ui.TabPanel} |
*/ |
ProfilingView = cr.ui.define(cr.ui.TabPanel); |
@@ -99,7 +99,7 @@ cr.define('gpu', function() { |
/////////////////////////////////////////////////////////////////////////// |
onSave_: function() { |
- this.overlayEl_ = new gpu.Overlay(); |
+ this.overlayEl_ = new tracing.Overlay(); |
this.overlayEl_.className = 'profiling-overlay'; |
var labelEl = document.createElement('div'); |
@@ -124,7 +124,7 @@ cr.define('gpu', function() { |
/////////////////////////////////////////////////////////////////////////// |
onLoad_: function() { |
- this.overlayEl_ = new gpu.Overlay(); |
+ this.overlayEl_ = new tracing.Overlay(); |
this.overlayEl_.className = 'profiling-overlay'; |
var labelEl = document.createElement('div'); |
@@ -4,14 +4,14 @@ |
/** |
- * @fileoverview ProfilingView visualizes GPU_TRACE events using the |
- * gpu.Timeline component. |
+ * @fileoverview ProfilingView visualizes TRACE_EVENT events using the |
+ * tracing.Timeline component. |
*/ |